RedactingSerializer

Struct RedactingSerializer 

pub struct RedactingSerializer<'a> { /* private fields */ }
CanonicalJsonObject serializer that redacts fields on the fly.

The main use case for this is to compute the hashes or signatures of an event, where the event needs to be redacted and have a few other fields removed.

This avoids having to .clone() a CanonicalJsonObject, and then to redact() it and potentially remove other fields, and serialize it with serde_json::to_vec().

Implementations

Source

impl<'a> RedactingSerializer<'a>

pub fn new() -> RedactingSerializer<'a>

Construct a new RedactingSerializer that doesn’t redact anything.

pub fn rules(self, rules: &'a RedactionRules) -> RedactingSerializer<'a>

Add the redaction rules to apply.

If this is set, the object to serialize must be an event with a type field.

pub fn custom_redacted_root_fields( self, fields: &'a [&'a str], ) -> RedactingSerializer<'a>

Add custom fields to redact at the root of the object.

pub fn serialize( &self, object: &BTreeMap<String, CanonicalJsonValue>, ) -> Result<String, Error>

Serialize the given object while redacting it.